@@ -17,6 +17,7 @@
 
 
 require 'ctioga2/data/backends/backend'
+require 'ctioga2/log'
 
 # We try to look for all files under a ctioga2/metabuilder/types
 # directory anywhere on the $: path
@@ -33,7 +34,7 @@ for file in files.uniq
   begin
     require "ctioga2/data/backends/backends/#{file}"
   rescue Exception => e
-    warn { "There was a problem trying to load 'ctioga2/data/backends/backends/#{file}': "  }
-    warn { "#{e.inspect}" }
+    CTioga2::Log::warn { "There was a problem trying to load 'ctioga2/data/backends/backends/#{file}': "  }
+    CTioga2::Log::warn { "#{e.inspect}" }
   end
 end
