@@ -18,9 +18,6 @@ require 'ctioga2/data/indexed-dtable'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 451 $', '$Date: 2013-08-29 01:28:30 +0200 (Thu, 29 Aug 2013) $')
-
-
   # \todo now, port the backend infrastructure...
 
   # This module holds all the code that deals with manipulation and
@@ -172,6 +169,11 @@ module CTioga2
         return 1 + @ys.size
       end
 
+      # The number of Z columns
+      def z_columns
+        return @ys.size - 1
+      end
+
       # Concatenates another Dataset to this one
       def <<(dataset)
         if dataset.size != self.size
