@@ -25,9 +25,6 @@ require 'ctioga2/data/filters'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 518 $', '$Date: 2013-09-19 21:43:58 +0200 (Thu, 19 Sep 2013) $')
-
-
   module Data
 
     # This is the central class for acquisition and handling of
@@ -92,7 +89,7 @@ EOH
       # backend, retrieves corresponding Dataset objects, pushes them
       # onto the stack and returns them.
       def get_datasets(set, options = {})
-        backend = @backend_factory.current
+        backend = @backend_factory.specified_backend(options)
         sets = backend.expand_sets(set)
         datasets = []
         for s in sets
@@ -319,6 +316,7 @@ EOH
 
     LoadDatasetOptions = { 
       'name' => CmdArg.new('text'),
+      'as' => CmdArg.new('text'),
       'where' => CmdArg.new('text'),
       'ignore_hooks' => CmdArg.new('boolean')
     }
