@@ -18,8 +18,6 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 535 $', '$Date: 2013-10-02 20:31:21 +0200 (Wed, 02 Oct 2013) $')
-
   # This module contains all graphical elements of CTioga2
   module Graphics
 
@@ -38,6 +36,7 @@ module CTioga2
         # LocationStyle object
         attr_writer :location
 
+        # Whether the object is clipped by default or not.
         attr_accessor :clipped
 
         
@@ -48,6 +47,8 @@ module CTioga2
           @clipped = true
 
           @depth = 50           # Hey, like xfig
+          
+          @gp_cache = {}
         end
 
         def depth
@@ -66,6 +67,7 @@ module CTioga2
         # redefine _do_ too if you need another debugging output.
         def do(f)
           debug { "plotting #{self.inspect}" }
+          @gp_cache = {}
           real_do(f)
         end
 
