@@ -21,8 +21,6 @@ require 'ctioga2/graphics/styles/plot-types'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 513 $', '$Date: 2013-09-19 00:43:28 +0200 (Thu, 19 Sep 2013) $')
-
   module Graphics
 
 
@@ -53,6 +51,11 @@ module CTioga2
       # parametric plots.
       attr_accessor :xy_parametric_parameters
 
+
+      # Style of histograms
+      attr_accessor :histogram_parameters
+
+
       # Creates a CurveGenerator object.
       def initialize
         @legend_provider = Legends::LegendProvider.new
@@ -60,6 +63,7 @@ module CTioga2
         @current_curves = :xy_plot
 
         @xy_parametric_parameters = Styles::ParametricPlotStyle.new
+        @histogram_parameters = Styles::HistogramStyle.new
       end
 
       PlotOptions = { 
@@ -87,8 +91,16 @@ module CTioga2
           CurveStyleFactory::PlotCommandOptions.key?(k)
         }
 
-        curve = send(@current_curves, plot, dataset, options)
-        curve.curve_style.target = curve
+        begin
+          legend = @legend_provider.dataset_legend(dataset)
+          style = @style_factory.next(options)
+          style.legend ||= legend # The legend specified as option to
+                                  # the --plot command has precedence
+                                  # over the one specified by
+                                  # --legend.
+          curve = send(@current_curves, dataset, style)
+          curve.curve_style.target = curve
+        end
         return curve
       end
 
@@ -96,56 +108,36 @@ module CTioga2
       
       ## \name Available kinds of curves
       ##
-      ## @todo All these are completely identical, there probably
-      ## isn't need for separate code ?
-      # 
-      # @{
-      # 
+      ## @{
+
+
       # The "classical" 2D plots.
-      def xy_plot(plot, dataset, options = {})
-        legend = @legend_provider.dataset_legend(dataset)
-        style = @style_factory.next(options)
-        style.legend ||= legend # The legend specified as option to
-                                # the --plot command has precedence
-                                # over the one specified by --legend.
-        curve = Graphics::Elements::Curve2D.new(dataset, style)
-        return curve
+      def xy_plot(dataset, style)
+        return Graphics::Elements::Curve2D.new(dataset, style)
+      end
+
+      # The "classical" 2D plots.
+      def histogram(dataset, style)
+        return Graphics::Elements::Histogram.new(dataset, style, 
+                                                 @histogram_parameters.dup)
       end
 
       # XYZ plots formerly known as "parametric plots"
-      def xy_parametric(plot, dataset, options = {})
-        legend = @legend_provider.dataset_legend(dataset)
-        style = @style_factory.next(options)
-        style.legend ||= legend # The legend specified as option to
-                                # the --plot command has precedence
-                                # over the one specified by --legend.
-        curve = Graphics::Elements::Parametric2D.
+      def xy_parametric(dataset, style)
+        return Graphics::Elements::Parametric2D.
           new(dataset, style, @xy_parametric_parameters.dup)
-        return curve
       end
 
       # XYZ maps
-      def xyz_map(plot, dataset, options = {})
-        legend = @legend_provider.dataset_legend(dataset)
-        style = @style_factory.next(options)
-        style.legend ||= legend # The legend specified as option to
-                                # the --plot command has precedence
-                                # over the one specified by --legend.
+      def xyz_map(dataset, style)
         style.legend = false    # No legend for XYZ maps
-        curve = Graphics::Elements::XYZMap.new(dataset, style)
-        return curve
+        return Graphics::Elements::XYZMap.new(dataset, style)
       end
 
       # XYZ maps
-      def xyz_contour(plot, dataset, options = {})
-        legend = @legend_provider.dataset_legend(dataset)
-        style = @style_factory.next(options)
-        style.legend ||= legend # The legend specified as option to
-                                # the --plot command has precedence
-                                # over the one specified by --legend.
-        style.legend = false    # No legend for XYZ maps
-        curve = Graphics::Elements::XYZContour.new(dataset, style)
-        return curve
+      def xyz_contour(dataset, style)
+        style.legend = false    # No legend for XYZ contours
+        return Graphics::Elements::XYZContour.new(dataset, style)
       end
 
 
@@ -174,6 +166,19 @@ module CTioga2
 Switch to XY parametric plots, that is standard XY plots whose appearance
 (such as color, marker color, and, potentially, marker kinds and more)
 are governed by one (or more ?) Z values.
+EOH
+
+    HistogramPlotCommand = 
+      Cmd.new("histogram",nil,"--histogram", 
+              [], Styles::HistogramStyle.options_hash) do |plotmaker, opts|
+      plotmaker.curve_generator.current_curves = :histogram
+      plotmaker.curve_generator.
+        histogram_parameters.set_from_hash(opts)
+    end
+    
+    HistogramPlotCommand.describe('select histogram plots', 
+                                  <<EOH, PlotTypesGroup)
+Switch to drawing histograms.
 EOH
 
     ContourPlotCommand = 
