@@ -158,8 +158,6 @@ require 'ctioga2/postprocess'
 # displays of rate constants vs potentials)
 module CTioga2
 
-  Version::register_svn_info('$Revision: 522 $', '$Date: 2013-09-22 12:02:48 +0200 (Sun, 22 Sep 2013) $')
-
   # This class is the core of ctioga. It parses the command-line arguments,
   # reads all necessary files and plots graphs. Most of its functionality
   # is delegated into classes.
@@ -357,11 +355,11 @@ module CTioga2
         fn = path.basename.to_s
 
         efn = fn.gsub(/[.\s]/) do |x|
-          "__#{x.ord}__"
+          "__#{x[0].ord}__"
         end
 
         if efn != fn
-          debug { "Mangled name to '#{fn}'"}
+          debug { "Mangled name to '#{efn}'"}
         end
 
         t.def_figure(efn) do
