@@ -17,4 +17,12 @@ $ct --setup-grid 1,2x2,1 --inset grid:1,0 'sin(x)' \
 
 # Additional specification
 $ct --setup-grid 1,2x2,1 --inset grid:1,0,xl=0.3 'sin(x)' \
-    --next-inset grid:0,1,yt=0.7,xr=0.9 'x**2'
\ No newline at end of file
+    --next-inset grid:0,1,yt=0.7,xr=0.9 'x**2'
+
+# Use of style sheets to simplify the handling of background/axes and
+# the like
+$ct --setup-grid 1,2x2,1 \
+    --define-background-style background /background_color=Pink \
+    /watermark='two line\\watermark' \
+    --inset grid:1,0 'sin(x)' \
+    --next-inset grid:0,1 'x**2'
\ No newline at end of file
